@@ -55,7 +55,7 @@ class CGAIPATH(object):
             if result[-1] in ignores:
                 result = result[:-1]
         except Exception as VERR:
-            print(VERR)
+            result = os.path.splitext(fullname)[0]
 
         return result
 
